@@ -36,13 +36,12 @@ class BaseWriter(object):
         raise NotImplementedError
 
     def run(self):
-        if g.detail_logging:
+        try:
             self.start()
-        else:
-            try:
-                self.start()
-            except Exception as e:
-                logging.error(e)
+        except Exception as e:
+            logging.error(e)
+            if g.interrupt:
+                raise e
 
         name = self.__class__.__name__
         logging.info('%s Finished' % name)
@@ -63,8 +62,7 @@ class BaseWriter(object):
     def render(self, params, template, destination):
         filepath = destination[len(g.output_directory) + 1:]
         filepath = filepath.lower()
-        if g.detail_logging:
-            logging.info('write %s' % filepath)
+        logging.debug('write %s' % filepath)
         tpl = g.jinja.get_template(template)
 
         writer = {
@@ -137,12 +135,12 @@ class Pagination(object):
 
 def find_theme():
     theme_name = settings.theme.get('name', 'default')
-    theme_gallary = [
+    theme_gallery = [
         os.path.join(os.path.abspath('_themes'), theme_name),
-        os.path.expanduser('~/.liquidluck-themes/%s' % theme_name),
+        os.path.join(g.theme_gallery, theme_name),
         os.path.join(g.liquid_directory, '_themes', theme_name),
     ]
-    for path in theme_gallary:
+    for path in theme_gallery:
         if os.path.exists(path):
             return path
 
@@ -191,6 +189,11 @@ def load_jinja():
     #: load theme variables
     config = {}
     theme_config = os.path.join(theme, 'settings.py')
+    if os.path.exists(theme_config):
+        logging.warn('settings.py in theme is deprecated since 3.4')
+        logging.warn('the name should be changed to theme.py')
+        execfile(theme_config, {}, config)
+    theme_config = os.path.join(theme, 'theme.py')
     if os.path.exists(theme_config):
         execfile(theme_config, {}, config)
 
